==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/2a/2a0ce13f464fdfa55898f3332c904949.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_454545_256x240.png */
class __TwigTemplate_93a886d4a999ea850743008e5e99321f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000Er@\000\000\000gAMA\000\000a\000\000\000 cHRM\000\000z&\000\000\000\000\000\000\000\000\000u0\000\000`\000\000:\000\000pQ<\000\000\000bKGD\000E;-\000\000\000tIME
%'E\000\000IDATxk%Gum;!^pl0[HXȹH\000:w8;g1s]&<\000Clfq؅!,\"·Wu׫{vGwn>UUuN=ΩSx4g
:6!Agb3 6+JD0&s؇N_B\000s&&ڏ>~=
c{vj%_DYEF
qܸG
RSơCEہ!'NP)~tϷ=;wהmeBH{\000s
S&S6MCP6z̐!(hnE6VjնcO6y7iʶ~fK\000jڬT0<26+^;\0004~%pxh8\0004^\000/\000
:2\000n6eLh`~=upr\000n0sOs횶WrGh _
Cmz-=)wFi#@u-cթPO{\000Ss˛^|BA'm\tTQn`.[ܫ
|Եt7^p@pxh8\0004^\000sC8UkN}A 栺*s\000%~\000aJYT}-1pTVP%%?p(>~PA.E
]1^([#\\ֱWRЃ>4j\"mhI@I>]yҙA6E:q7n05AuPy
L8PjK9
[EZ.Ȫ.Lu֛L;Xt0Ua29@às_!_\tl8\0004^\000/\000
@7R?~¥\\4F>R7F{VCl9wT.[)?}ڕk Po5othz'\\CVgskۥb%@6[\\ܩ۶`6YsKݞs7jAAnX2G?1R6+u
\000W@P\"[U|~mm`3` \000{H+\"ȤN=Mϯ4U `z~S=n0o粤=\t̙hJ#[4ٗv4`5@bt
n0w59-̩B(X'[67i3SP@\t Ĥ/7^\000/\000
@:\0006U.EowsXE{\000LsUXcau7WvR҅l~٭Nv]h;Іi;MGC'{I79J*Fͦ>B\\u}A窞o<ȟVaCHP\"nLum߼]݅=eMFdUf;Il;:DCߪiŪ'Ƚǐ_VL:ps/5V\000.~{3R[\000IAH]\$fCT5Pہ(Ku^([ݬN4]&E@.`C5oJ@pxh8\0004'\000Җ:6lB'.D
Рxw5%1\\U)F:Jm^[uRdTwOtI&~|Uͩzq;j~đ
TsD_S>ܵ\tTG4m5'W:m\" VH#t|dMnz:um?bGA-<[ez#S/\\хyDV{+
@u6y#L<\"<]5d\tlj&˺'Y%iFbgJAH}P=o2O౩pxh8\0004\$\000Jl_ҿAwp(
UNQ߆'\$kLe>Wƞ%ײ:RfQkb½?.ux8LPr07jNװOfX˼I\\99Tn?S#Z֙kk@g?mbiʘ,kċr]=
JOE*We~ 4\t-E,dN9wuʬqw>c3e|q\000EwKځ3%,\000y ]Y\$p)CǢyR<KۿK}AHD`!@}Enevp7/
4shVTʉXJ`ג\t~\\#gᅑ./T!Ij|*<^T@+]uƜO\teә\"O><Y\\U\000s\000h&( 80h'yWǣ):)yMjmv/\t୅{GyNh/(?_iRr5^z\000,b\\S
,OqxYM`/*6x\000g2
%sT2iW6BE!\000Sr4G-2-ՕAE~5ΝfӅ^f%ؑVU ڹ<b2a@`F^3ڦD\00027\t\\9FUK4\000s׼2t;_E\000!|PDN'W:\$n|XNr`b=b?L\000K3ԍE
2usXf0\t@0J\000
pxh8\0004^\000FeN1[70ԨetŷC_޲H~Dܬ|\000O'PXbG5E9`^aGy3T>^(/檜}cݾ~[\"ɯx·z&\000\$u7@L&ir=Ggjw)ZLZsܗ\000~M+@>7pZOI'y#GSAS^zUK!;4Og0͂_]%=e`d
ԣ=K?RPz12Ӎ-x9uJZ[Ԛ[@byvp#ai.\\wiC#Y.ǵꚸM*R6ȩ-~\000f\000Z>Ohզ:as|3|*f0S}a?~oVJ]@l,5}c×%ESԸՙ_T\t!co`_Xpj9C>|\"qOꁾKt͝i'
t #{P&rej5hv^M8GEh&]@X\000֔AfaJɂH*_VnX3ug<}hrPPv!o[@[DF- 2)oCOSP{y#\\_.1C|ܼ],ҥKY단Kssͅd
w2L)߰O˾e+'HL\$1
?Ѽz>!0r>:xGtb*h8.pxh8\0004\0006VtU9Oyw莇!+\000IT
.ZvZF
\"pS΃ѯ?!p!B|5CޞH(zzi8[97Q{
z_b:LXTO>٭E {R\\)|er}o+BO#/}WH6gvs!Pf^3d\"#Qgh8la0`XJ&ɂ\000`7;a\tE
EO8SҿLD_:ZQz2*T55XQ{8!WfS~!a89'JHSle'@&3YE,_ɷx1O\000\tWP1E#u3jkEyg\\iQbp-;;ť\\{ǔU5e)6ti,UJ6os&X!\000؉N3˔A!
:)OFH*V3\0009g[yTΞ,FU
&_C<ҫ(_?(W1p?OW\tp!3J8ҨoWd'`9MYa,3˳|ClSŦ.׳wU!ܟzBļ:b ؑr@jvx_\tE4X3|8Wi5gqqp/+3v+s+Q7].v)gp
(6G,(6G?Xd ou'p\0000M:nCfF/?>mO΅ؑT^rR[M)<#5Ќݤ>;rZs[{uY0c?]yUm-~/d|d7?C
e_>DѡWg>iKݑX8ƫ
\"J\000fqvqxh8p_]|-Yw
:o\\+
>%W7:r\000.\\+tW#*Oԃؗq!TFQu~rÁ\000\t&(_=q~}`_ƳCN%EHs
hkQEϬ6\\PO6/I
m!ƹClg>҅ 1O 6X}G.M.W@@,TKD6k,s?ofR\"vޣMt2'zlY=@'Ӥ>U?Rω;}]q?ko)\\LXfӜ4X jJĽAonLٮg{SaDVf2n2tdcj˚k\$Ongyv'C46ާ~4=MI3dF9ݑW=\tdH!R
u}8o=-p`\$^/Oe4V\000<F^pxh8\0004^\000/\000
<:F@Ǫ1b
@ȆEԻ#!'xHm:VK-
OKBHa BQЏH)DP<wW~-`*dބC)^H~M_T^\000thS<ې@_.UvFmȊZ\000@}M\000 6B鯍yXR\t>F/X[II
V=zd1abXC
:oFE,(`p4lbZD'OWA]4RCC-yЍis'/US\$CC#\\r=hLݒï6^\000/\000
@Ñ\000[D*\000->
Mk_>zlIТ3,ruX(+d<dBqv%^IgPY=:-*%]~E#grboncLE8ȝ6ΰO;㚌u5>zAC&\000C&gIZP
b\000sb/p.o'G+o^_n\\!\t噻/\000fvq=fJ>yOeĢHES|fD<`gizI>7p5SZت!{y{~=4@#˹5\"p@yU8ZSq\t?*66x{ϖ/\000
@Ñ
<п8~o>U8/y\000u67s|Wٿpo.P<]ץƟ/Doz7hz
! 6*Uyjr6~`oK?B?o˿9iic.ͅ%wvms%]\\7}U]7%~T\000_|JOvh務Ѹ[鄚{ [@+r.~ٳuĭO\"2#f`Ͽ=MMv7Q}WLZnJߔB &\000+\$U=\t;T=(r/Kj+oد~jI8&e 1Uyz;6~hoK?B?o˿)~yUY: uRXX
^fNK)Fi޲i~o\0008KX/pu97:dس~o!
6^\000/\000
@*l;ݣdmxr]1t(XnM^
j!!/\0006nt1P;FXQA^\000qƍtCTxDqۜBk 3||9/`/\000
@pl]h^@l!=mV\$!3hZ`꠳9
`x_ akݞ=k.|!,!ثØ~A+l[U?d0\000ğrB0_S<ҥI_~?\000CWS|3ȇɲ_>Nք(azX>E\000=<Y=kuo\tUX0\000\000\000%tEXtdate:create\0002016-09-14T13:32:39-04:00z\000\000\000%tEXtdate:modify\0002015-06-01T10:37:21-04:00(An\000\000\000tEXtSoftware\000Adobe ImageReadyqe<\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_454545_256x240.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_454545_256x240.png", "/var/www/mautic-ktn/app/bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_454545_256x240.png");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/2a/2a0ce13f464fdfa55898f3332c904949.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_454545_256x240.png */
class __TwigTemplate_93a886d4a999ea850743008e5e99321f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000\000\000\000\000Er@\000\000\000gAMA\000\000a\000\000\000 cHRM\000\000z&\000\000\000\000\000\000\000\000\000u0\000\000`\000\000:\000\000pQ<\000\000\000bKGD\000E;-\000\000\000tIME
%'E\000\000IDATxk%Gum;!^pl0[HXȹH\000:w8;g1s]&<\000Clfq؅!,\"·Wu׫{vGwn>UUuN=ΩSx4g
:6!Agb3 6+JD0&s؇N_B\000s&&ڏ>~=
c{vj%_DYEF
qܸG
RSơCEہ!'NP)~tϷ=;wהmeBH{\000s
S&S6MCP6z̐!(hnE6VjնcO6y7iʶ~fK\000jڬT0<26+^;\0004~%pxh8\0004^\000/\000
:2\000n6eLh`~=upr\000n0sOs횶WrGh _
Cmz-=)wFi#@u-cթPO{\000Ss˛^|BA'm\tTQn`.[ܫ
|Եt7^p@pxh8\0004^\000sC8UkN}A 栺*s\000%~\000aJYT}-1pTVP%%?p(>~PA.E
]1^([#\\ֱWRЃ>4j\"mhI@I>]yҙA6E:q7n05AuPy
L8PjK9
[EZ.Ȫ.Lu֛L;Xt0Ua29@às_!_\tl8\0004^\000/\000
@7R?~¥\\4F>R7F{VCl9wT.[)?}ڕk Po5othz'\\CVgskۥb%@6[\\ܩ۶`6YsKݞs7jAAnX2G?1R6+u
\000W@P\"[U|~mm`3` \000{H+\"ȤN=Mϯ4U `z~S=n0o粤=\t̙hJ#[4ٗv4`5@bt
n0w59-̩B(X'[67i3SP@\t Ĥ/7^\000/\000
@:\0006U.EowsXE{\000LsUXcau7WvR҅l~٭Nv]h;Іi;MGC'{I79J*Fͦ>B\\u}A窞o<ȟVaCHP\"nLum߼]݅=eMFdUf;Il;:DCߪiŪ'Ƚǐ_VL:ps/5V\000.~{3R[\000IAH]\$fCT5Pہ(Ku^([ݬN4]&E@.`C5oJ@pxh8\0004'\000Җ:6lB'.D
Рxw5%1\\U)F:Jm^[uRdTwOtI&~|Uͩzq;j~đ
TsD_S>ܵ\tTG4m5'W:m\" VH#t|dMnz:um?bGA-<[ez#S/\\хyDV{+
@u6y#L<\"<]5d\tlj&˺'Y%iFbgJAH}P=o2O౩pxh8\0004\$\000Jl_ҿAwp(
UNQ߆'\$kLe>Wƞ%ײ:RfQkb½?.ux8LPr07jNװOfX˼I\\99Tn?S#Z֙kk@g?mbiʘ,kċr]=
JOE*We~ 4\t-E,dN9wuʬqw>c3e|q\000EwKځ3%,\000y ]Y\$p)CǢyR<KۿK}AHD`!@}Enevp7/
4shVTʉXJ`ג\t~\\#gᅑ./T!Ij|*<^T@+]uƜO\teә\"O><Y\\U\000s\000h&( 80h'yWǣ):)yMjmv/\t୅{GyNh/(?_iRr5^z\000,b\\S
,OqxYM`/*6x\000g2
%sT2iW6BE!\000Sr4G-2-ՕAE~5ΝfӅ^f%ؑVU ڹ<b2a@`F^3ڦD\00027\t\\9FUK4\000s׼2t;_E\000!|PDN'W:\$n|XNr`b=b?L\000K3ԍE
2usXf0\t@0J\000
pxh8\0004^\000FeN1[70ԨetŷC_޲H~Dܬ|\000O'PXbG5E9`^aGy3T>^(/檜}cݾ~[\"ɯx·z&\000\$u7@L&ir=Ggjw)ZLZsܗ\000~M+@>7pZOI'y#GSAS^zUK!;4Og0͂_]%=e`d
ԣ=K?RPz12Ӎ-x9uJZ[Ԛ[@byvp#ai.\\wiC#Y.ǵꚸM*R6ȩ-~\000f\000Z>Ohզ:as|3|*f0S}a?~oVJ]@l,5}c×%ESԸՙ_T\t!co`_Xpj9C>|\"qOꁾKt͝i'
t #{P&rej5hv^M8GEh&]@X\000֔AfaJɂH*_VnX3ug<}hrPPv!o[@[DF- 2)oCOSP{y#\\_.1C|ܼ],ҥKY단Kssͅd
w2L)߰O˾e+'HL\$1
?Ѽz>!0r>:xGtb*h8.pxh8\0004\0006VtU9Oyw莇!+\000IT
.ZvZF
\"pS΃ѯ?!p!B|5CޞH(zzi8[97Q{
z_b:LXTO>٭E {R\\)|er}o+BO#/}WH6gvs!Pf^3d\"#Qgh8la0`XJ&ɂ\000`7;a\tE
EO8SҿLD_:ZQz2*T55XQ{8!WfS~!a89'JHSle'@&3YE,_ɷx1O\000\tWP1E#u3jkEyg\\iQbp-;;ť\\{ǔU5e)6ti,UJ6os&X!\000؉N3˔A!
:)OFH*V3\0009g[yTΞ,FU
&_C<ҫ(_?(W1p?OW\tp!3J8ҨoWd'`9MYa,3˳|ClSŦ.׳wU!ܟzBļ:b ؑr@jvx_\tE4X3|8Wi5gqqp/+3v+s+Q7].v)gp
(6G,(6G?Xd ou'p\0000M:nCfF/?>mO΅ؑT^rR[M)<#5Ќݤ>;rZs[{uY0c?]yUm-~/d|d7?C
e_>DѡWg>iKݑX8ƫ
\"J\000fqvqxh8p_]|-Yw
:o\\+
>%W7:r\000.\\+tW#*Oԃؗq!TFQu~rÁ\000\t&(_=q~}`_ƳCN%EHs
hkQEϬ6\\PO6/I
m!ƹClg>҅ 1O 6X}G.M.W@@,TKD6k,s?ofR\"vޣMt2'zlY=@'Ӥ>U?Rω;}]q?ko)\\LXfӜ4X jJĽAonLٮg{SaDVf2n2tdcj˚k\$Ongyv'C46ާ~4=MI3dF9ݑW=\tdH!R
u}8o=-p`\$^/Oe4V\000<F^pxh8\0004^\000/\000
<:F@Ǫ1b
@ȆEԻ#!'xHm:VK-
OKBHa BQЏH)DP<wW~-`*dބC)^H~M_T^\000thS<ې@_.UvFmȊZ\000@}M\000 6B鯍yXR\t>F/X[II
V=zd1abXC
:oFE,(`p4lbZD'OWA]4RCC-yЍis'/US\$CC#\\r=hLݒï6^\000/\000
@Ñ\000[D*\000->
Mk_>zlIТ3,ruX(+d<dBqv%^IgPY=:-*%]~E#grboncLE8ȝ6ΰO;㚌u5>zAC&\000C&gIZP
b\000sb/p.o'G+o^_n\\!\t噻/\000fvq=fJ>yOeĢHES|fD<`gizI>7p5SZت!{y{~=4@#˹5\"p@yU8ZSq\t?*66x{ϖ/\000
@Ñ
<п8~o>U8/y\000u67s|Wٿpo.P<]ץƟ/Doz7hz
! 6*Uyjr6~`oK?B?o˿9iic.ͅ%wvms%]\\7}U]7%~T\000_|JOvh務Ѹ[鄚{ [@+r.~ٳuĭO\"2#f`Ͽ=MMv7Q}WLZnJߔB &\000+\$U=\t;T=(r/Kj+oد~jI8&e 1Uyz;6~hoK?B?o˿)~yUY: uRXX
^fNK)Fi޲i~o\0008KX/pu97:dس~o!
6^\000/\000
@*l;ݣdmxr]1t(XnM^
j!!/\0006nt1P;FXQA^\000qƍtCTxDqۜBk 3||9/`/\000
@pl]h^@l!=mV\$!3hZ`꠳9
`x_ akݞ=k.|!,!ثØ~A+l[U?d0\000ğrB0_S<ҥI_~?\000CWS|3ȇɲ_>Nք(azX>E\000=<Y=kuo\tUX0\000\000\000%tEXtdate:create\0002016-09-14T13:32:39-04:00z\000\000\000%tEXtdate:modify\0002015-06-01T10:37:21-04:00(An\000\000\000tEXtSoftware\000Adobe ImageReadyqe<\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_454545_256x240.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_454545_256x240.png", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/js/libraries/filemanager/jquery-ui/themes/smoothness/images/ui-icons_454545_256x240.png");
    }
}
